@@ -1,5 +1,5 @@
-from keras.models import Model
-from keras.layers import Dense, Input
+from tensorflow.keras.models import Model
+from tensorflow.keras.layers import Dense, Input
 import numpy as np
 from raise_utils.learners.learner import Learner
 
@@ -9,7 +9,7 @@ class Autoencoder(Learner):
     A standard autoencoder architecture.
     """
 
-    def __init__(self, n_layers: int = 2, n_units: list = [10, 10], n_out: int = 10, n_epochs=500, verbose=1, *args, **kwargs):
+    def __init__(self, n_layers: int = 2, n_units: list = [10, 10], n_out: int = 10, n_epochs=500, activation='relu', verbose=1, *args, **kwargs):
         """
         Initializes the autoencoder.
 
@@ -23,16 +23,17 @@ class Autoencoder(Learner):
 
         self.n_layers = n_layers
         self.n_units = n_units
-        self.n_epochs = 500
+        self.n_epochs = n_epochs
         self.n_out = n_out
         self.verbose = verbose
         self.loss = 'mse'
-        self.activation = 'relu'
+        self.activation = activation
 
         self.learner = self
         self.random_map = {
             'n_layers': (1, 3),
-            'n_out': (5, 11)
+            'n_out': (5, 11),
+            'activation': ['relu', 'selu']
         }
         self._instantiate_random_vals()
 
